==> haskell-statistics-0.16.3.0-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 statistics
version:              0.16.3.0
visibility:           public
id:                   statistics-0.16.3.0-BanQckL4QvF4IL5LXbGehV
key:                  statistics-0.16.3.0-BanQckL4QvF4IL5LXbGehV
license:              BSD-2-Clause
copyright:            2009-2014 Bryan O'\''Sullivan
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/haskell/statistics
synopsis:             A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.
    .
    The library'\''s facilities can be divided into four broad categories:
    .
    * Working with widely used discrete and continuous probability
      distributions.  (There are dozens of exotic distributions in use;
      we focus on the most common.)
    .
    * Computing with sample data: quantile estimation, kernel density
      estimation, histograms, bootstrap methods, significance testing,
      and regression and autocorrelation analysis.
    .
    * Random variate generation under several different distributions.
    .
    * Common statistical tests for significant differences between
      samples.

category:             Math, Statistics
abi:                  eeb58aba53abe42f4457541f92418717
exposed:              True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Lognormal
    Statistics.Distribution.NegativeBinomial
    Statistics.Distribution.Normal Statistics.Distribution.Poisson
    Statistics.Distribution.StudentT Statistics.Distribution.Transform
    Statistics.Distribution.Uniform Statistics.Distribution.Weibull
    Statistics.Function Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Normalize
    Statistics.Sample.Powers Statistics.Test.ChiSquared
    Statistics.Test.KolmogorovSmirnov Statistics.Test.KruskalWallis
    Statistics.Test.MannWhitneyU Statistics.Test.StudentT
    Statistics.Test.Types Statistics.Test.WilcoxonT
    Statistics.Transform Statistics.Types

hidden-modules:
    Statistics.Distribution.Poisson.Internal Statistics.Internal
    Statistics.Test.Internal Statistics.Types.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-statistics
hs-libraries:         HSstatistics-0.16.3.0-BanQckL4QvF4IL5LXbGehV
depends:
    aeson-2.1.2.1-J19dEw13kUOF5hLEOQVj2r
    async-2.2.5-BcqMz9kSLpQJiwvDzQjiwa base-4.17.2.1 binary-0.8.9.1
    data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi deepseq-1.4.8.0
    dense-linear-algebra-0.1.0.0-AAjnyUfvCGoARrtUVYFO23
    math-functions-0.3.4.4-Hnwbmejvn372oAq5zVChEQ
    mwc-random-0.15.2.0-IHP9LPV2jV93yBVZO1pbK7
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    primitive-0.9.1.0-2rF1KRuV9tjItame9gIzcT
    random-1.2.1.3-8yAn85BRVsALc4v1F70S7L
    vector-0.13.2.0-FNdsFzivQrc5gVfjRMxS7n
    vector-algorithms-0.9.1.0-3oABcFQEDJ42cLgrA7UZCI
    vector-binary-instances-0.2.5.2-H1b7sHFbkYrCTzTQ9i4R9x
    vector-th-unbox-0.2.2-D2enge3Beg426hD67pQ8bb

haddock-interfaces:   /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html:         /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statistics-0.16.3.0-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 statistics
version:              0.16.3.0
visibility:           public
id:                   statistics-0.16.3.0-11cxH8BuX1fK4yatL0NTJ4
key:                  statistics-0.16.3.0-11cxH8BuX1fK4yatL0NTJ4
license:              BSD-2-Clause
copyright:            2009-2014 Bryan O'\''Sullivan
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/haskell/statistics
synopsis:             A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.
    .
    The library'\''s facilities can be divided into four broad categories:
    .
    * Working with widely used discrete and continuous probability
      distributions.  (There are dozens of exotic distributions in use;
      we focus on the most common.)
    .
    * Computing with sample data: quantile estimation, kernel density
      estimation, histograms, bootstrap methods, significance testing,
      and regression and autocorrelation analysis.
    .
    * Random variate generation under several different distributions.
    .
    * Common statistical tests for significant differences between
      samples.

category:             Math, Statistics
abi:                  27b2cd67ef9c7fb7f888091f0276f69d
exposed:              True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Lognormal
    Statistics.Distribution.NegativeBinomial
    Statistics.Distribution.Normal Statistics.Distribution.Poisson
    Statistics.Distribution.StudentT Statistics.Distribution.Transform
    Statistics.Distribution.Uniform Statistics.Distribution.Weibull
    Statistics.Function Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Normalize
    Statistics.Sample.Powers Statistics.Test.ChiSquared
    Statistics.Test.KolmogorovSmirnov Statistics.Test.KruskalWallis
    Statistics.Test.MannWhitneyU Statistics.Test.StudentT
    Statistics.Test.Types Statistics.Test.WilcoxonT
    Statistics.Transform Statistics.Types

hidden-modules:
    Statistics.Distribution.Poisson.Internal Statistics.Internal
    Statistics.Test.Internal Statistics.Types.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-statistics
hs-libraries:         HSstatistics-0.16.3.0-11cxH8BuX1fK4yatL0NTJ4
depends:
    aeson-2.1.2.1-wY4CXNP4Ti6TCaMY1tyMf
    async-2.2.5-HgJvyv8nLlGBOZUsxEMYyx base-4.17.2.1 binary-0.8.9.1
    data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi deepseq-1.4.8.0
    dense-linear-algebra-0.1.0.0-G68TTcJWH8QEPQrnBau2sX
    math-functions-0.3.4.4-KLNCShrz7eTFsk8jBTbBtQ
    mwc-random-0.15.2.0-Ju3ryxETtMS80kt2wNPIm0
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    primitive-0.9.1.0-49xiE5QgfWiA4gs3utiGrq
    random-1.2.1.3-7z4mPLTBPidE9rbVioKqnW
    vector-0.13.2.0-B5pfN7kp2sVHpMWItbJQ58
    vector-algorithms-0.9.1.0-DEbpoqGwfzSDnvjhMo3s2C
    vector-binary-instances-0.2.5.2-32UgcjiSUTJHReRi1ysSFf
    vector-th-unbox-0.2.2-4LX5jODPKIW8Dm4PdMO74c

haddock-interfaces:   /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html:         /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
